<?xml version="1.0" encoding="UTF-8"?>
<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns="http://purl.org/rss/1.0/" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:syn="http://purl.org/rss/1.0/modules/syndication/" xmlns:admin="http://webns.net/mvcb/">
  <channel rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler">
    <title>gmane.comp.freedesktop.poppler</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler</link>
    <description/>
    <syn:updatePeriod>hourly</syn:updatePeriod>
    <syn:updateFrequency>1</syn:updateFrequency>
    <syn:updateBase>1901-01-01T00:00+00:00</syn:updateBase>
    <items>
      <rdf:Seq>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7140"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7139"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7138"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7137"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7136"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7135"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7134"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7133"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7132"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7131"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7130"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7129"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7128"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7127"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7126"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7125"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7124"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7123"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7122"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7121"/>
      </rdf:Seq>
    </items>
    <image rdf:resource="http://gmane.org/img/gmane-25t.png"/>
    <textinput rdf:resource=""/>
  </channel>
  <image rdf:about="http://gmane.org/img/gmane-25t.png">
    <title>Gmane</title>
    <url>http://gmane.org/img/gmane-25t.png</url>
    <link>http://gmane.org</link>
  </image>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7140">
    <title>Re: Annotation creation using Poppler</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7140</link>
    <description>&lt;pre&gt;Fabio,

Sorry, I was specifying wrong coordinates...

Now I am able to annotate a document using Poppler::LineAnnotation 
objects (am I correct if I assume that coordinates are given as 
percentages of the page size?) and to view them on various PDF Viewers.

I am also able to add Poppler::TextAnnotation's to a document.

However they appear as an icon when I open the document (bot using the 
poppler_qt4viewer distributed with Poppler and using Nitro PDF). Are 
there settings that allow to view them "exploded", i.e, with their 
associated text displayed on one the PDF page's sides?

Thanks and best regards,
Francesco.

-------- Original Message --------
Subject: Re: [poppler] Annotation creation using Poppler
Date: Thu, 24 May 2012 17:46:21 +0200
From: Francesco Gabbanini &amp;lt;fgabbanini&amp;lt; at &amp;gt;gmail.com&amp;gt;
To: poppler&amp;lt; at &amp;gt;lists.freedesktop.org



Many thanks for your help Fabio!

I have tryed to work on your example and wrote the following code:

Poppler::LineAnnotation *ia = new 
Poppler::LineAnnotation(Poppler::LineAn&lt;/pre&gt;</description>
    <dc:creator>Francesco Gabbanini</dc:creator>
    <dc:date>2012-05-25T12:34:32</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7139">
    <title>qt4: Keep page rotation into account when normalizingannotation coords</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7139</link>
    <description>&lt;pre&gt;qt4: Keep page rotation into account when normalizing annotation coords

If the page is rotated by 90 or 270 degrees, width and height need to be 
swapped ( just like in Page::pageSizeF() ).

Fabio
_______________________________________________
poppler mailing list
poppler&amp;lt; at &amp;gt;lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/poppler
&lt;/pre&gt;</description>
    <dc:creator>Fabio D'Urso</dc:creator>
    <dc:date>2012-05-24T21:48:59</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7138">
    <title>poppler/Annot.cc poppler/Annot.h poppler/Page.ccpoppler/Page.h qt4/src</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7138</link>
    <description>&lt;pre&gt; poppler/Annot.cc              |   40 ++++++++++++++++++++++++++++++++++------
 poppler/Annot.h               |   13 +++++++++----
 poppler/Page.cc               |    7 ++++---
 poppler/Page.h                |    2 +-
 qt4/src/poppler-annotation.cc |    8 --------
 5 files changed, 48 insertions(+), 22 deletions(-)

New commits:
commit ba6406222f828e354323223fc4bdb01c1726fb49
Author: Fabio D'Urso &amp;lt;fabiodurso&amp;lt; at &amp;gt;hotmail.it&amp;gt;
Date:   Mon May 21 18:16:06 2012 +0200

    Added Annot::removeReferencedObjects + Always set annotations' page field
    
    - Now Page::removeAnnot calls Annot::removeReferencedObjects, which takes care of
      removing referenced objects (such as the annot popup and the appearance streams).
    - Previously, Annot's page field was set only if the annotation dictionary
      contained /P

diff --git a/poppler/Annot.cc b/poppler/Annot.cc
index 8e1e760..9778bd2 100644
--- a/poppler/Annot.cc
+++ b/poppler/Annot.cc
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -1185,6 +1185,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; void Annot::initialize(PDFDoc *docA, Dict *dict) {
   }
&lt;/pre&gt;</description>
    <dc:creator>Carlos Garcia Campos</dc:creator>
    <dc:date>2012-05-24T17:49:31</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7137">
    <title>Re: [PATCH] Annotation removal improvements</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7137</link>
    <description>&lt;pre&gt;El Dijous, 24 de maig de 2012, a les 11:50:37, Carlos Garcia Campos va 
escriure:

Please :-)

Albert

&lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-24T16:24:02</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7136">
    <title>Re: Annotation creation using Poppler</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7136</link>
    <description>&lt;pre&gt;Many thanks for your help Fabio!

I have tryed to work on your example and wrote the following code:

Poppler::LineAnnotation *ia = new 
Poppler::LineAnnotation(Poppler::LineAnnotation::StraightLine);
QLinkedList&amp;lt;QPointF&amp;gt; points;
points.push_back(QPointF(50, 50));
points.push_back(QPointF(150, 150));

ia-&amp;gt;setLinePoints(points);
Poppler::Annotation::Style style;
style.setColor(QColor(0, 0, 0));
style.setWidth(4.0);
ia-&amp;gt;setStyle(style);

Poppler::Page *p = _doc-&amp;gt;page(npage);
p-&amp;gt;addAnnotation(ia);

Poppler::PDFConverter *conv = _doc-&amp;gt;pdfConverter();
conv-&amp;gt;setOutputFileName(QString("C:/Users/.../test.pdf"));
conv-&amp;gt;setPDFOptions(conv-&amp;gt;pdfOptions() | 
Poppler::PDFConverter::WithChanges);
conv-&amp;gt;convert();

I then tried to open the document with Nitro PDF Professional.
It seems that the annotation is there, because it is displayed by Nitro 
PDF when I click on the "Comments" button, but I cannot see it on the 
screen (I expected to see it drawn over the document).
I also tried to open the PDF with the Chrome browser&lt;/pre&gt;</description>
    <dc:creator>Francesco Gabbanini</dc:creator>
    <dc:date>2012-05-24T15:46:21</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7135">
    <title>Re: [PATCH] Annotation removal improvements</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7135</link>
    <description>&lt;pre&gt;Excerpts from Albert Astals Cid's message of mié may 23 20:01:08 +0200 2012:

Yes.


Yes, master only, do you want me to push it?

&lt;/pre&gt;</description>
    <dc:creator>Carlos Garcia Campos</dc:creator>
    <dc:date>2012-05-24T09:50:37</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7134">
    <title>Branch 'poppler-0.20' - 3 commits -glib/poppler-document.cc poppler/FontInfo.ccpoppler/GlobalParams.cc poppler/GlobalParamsWin.cc</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7134</link>
    <description>&lt;pre&gt; glib/poppler-document.cc   |    4 +--
 poppler/FontInfo.cc        |    1 
 poppler/GlobalParams.cc    |   58 ++++++++++++++++++++++++---------------------
 poppler/GlobalParamsWin.cc |    5 +++
 4 files changed, 39 insertions(+), 29 deletions(-)

New commits:
commit 9904b8f10abf068a7816bd90976ccbb320387645
Author: Adrian Johnson &amp;lt;ajohnson&amp;lt; at &amp;gt;redneon.com&amp;gt;
Date:   Thu May 24 18:24:48 2012 +0930

    glib docs: fix typo

diff --git a/glib/poppler-document.cc b/glib/poppler-document.cc
index 2b01c29..24badd9 100644
--- a/glib/poppler-document.cc
+++ b/glib/poppler-document.cc
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -1721,7 +1721,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; poppler_fonts_iter_get_name (PopplerFontsIter *iter)
  * The name of the substitute font of the font associated with &amp;lt; at &amp;gt;iter or %NULL if
  * the font is embedded
  *
- * Returns: the name of the substitute font or %NULL y font is emebedded
+ * Returns: the name of the substitute font or %NULL if font is embedded
  *
  * Since: 0.20
  */
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -1748,7 +1748,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; poppler_fonts_iter_get_substitute_name (PopplerFontsIter *iter)
 &lt;/pre&gt;</description>
    <dc:creator>Adrian Johnson</dc:creator>
    <dc:date>2012-05-24T09:01:24</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7133">
    <title>3 commits - glib/poppler-document.cc poppler/FontInfo.ccpoppler/GlobalParams.cc poppler/GlobalParamsWin.cc</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7133</link>
    <description>&lt;pre&gt; glib/poppler-document.cc   |    4 +--
 poppler/FontInfo.cc        |    1 
 poppler/GlobalParams.cc    |   58 ++++++++++++++++++++++++---------------------
 poppler/GlobalParamsWin.cc |    5 +++
 4 files changed, 39 insertions(+), 29 deletions(-)

New commits:
commit b47d38e2ccd8563394df89765e277bde95730052
Author: Adrian Johnson &amp;lt;ajohnson&amp;lt; at &amp;gt;redneon.com&amp;gt;
Date:   Thu May 24 18:24:48 2012 +0930

    glib docs: fix typo

diff --git a/glib/poppler-document.cc b/glib/poppler-document.cc
index d404fcd..e626a2a 100644
--- a/glib/poppler-document.cc
+++ b/glib/poppler-document.cc
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -1834,7 +1834,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; poppler_fonts_iter_get_name (PopplerFontsIter *iter)
  * The name of the substitute font of the font associated with &amp;lt; at &amp;gt;iter or %NULL if
  * the font is embedded
  *
- * Returns: the name of the substitute font or %NULL y font is emebedded
+ * Returns: the name of the substitute font or %NULL if font is embedded
  *
  * Since: 0.20
  */
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -1861,7 +1861,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; poppler_fonts_iter_get_substitute_name (PopplerFontsIter *iter)
 &lt;/pre&gt;</description>
    <dc:creator>Adrian Johnson</dc:creator>
    <dc:date>2012-05-24T08:56:51</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7132">
    <title>Re: [PATCH] [CMake] Fix automagic lcms dependencies</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7132</link>
    <description>&lt;pre&gt;
That's... correct.
I could fix it to match expected behaviour, but I may have a better idea, how 
about doing it the same way --enable-cms is handled:
- if -DENABLE_CMS=lcms1 then only look for liblcms1
- if -DENABLE_CMS=lcms2 then only look for liblcms2
- otherwise look for lcms2, if not found, then try lcms1 as fallback

&lt;/pre&gt;</description>
    <dc:creator>Maciej Mrozowski</dc:creator>
    <dc:date>2012-05-23T19:39:27</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7131">
    <title>Re: Annotation creation using Poppler</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7131</link>
    <description>&lt;pre&gt;El Dimecres, 23 de maig de 2012, a les 19:59:13, Albert Astals Cid va 
escriure:

Actually since it was private noone could have a "handle" to it, so it's not a 
problem if the signature is changed since noone is listening, so i've pushed 
to 0.20 too.

Albert

&lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-23T18:25:46</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7130">
    <title>Branch 'poppler-0.20' - qt4/src</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7130</link>
    <description>&lt;pre&gt; qt4/src/poppler-annotation.h |    2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 1c6e84555572a6bf3a2e3fbe9a54b40f11c122ad
Author: Fabio D'Urso &amp;lt;fabiodurso&amp;lt; at &amp;gt;hotmail.it&amp;gt;
Date:   Fri May 18 16:22:46 2012 +0200

    qt4: Make TextAnnotation ctor public

diff --git a/qt4/src/poppler-annotation.h b/qt4/src/poppler-annotation.h
index b897603..e511ec0 100644
--- a/qt4/src/poppler-annotation.h
+++ b/qt4/src/poppler-annotation.h
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -302,6 +302,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; class POPPLER_QT4_EXPORT TextAnnotation : public Annotation
     enum TextType { Linked, InPlace };
     enum InplaceIntent { Unknown, Callout, TypeWriter };
 
+    TextAnnotation( TextType type );
     virtual ~TextAnnotation();
     virtual SubType subType() const;
 
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -360,7 +361,6 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; class POPPLER_QT4_EXPORT TextAnnotation : public Annotation
     void setInplaceIntent( InplaceIntent intent );
 
   private:
-    TextAnnotation( TextType type );
     TextAnnotation( const QDomNode &amp;amp;node );
     TextAnnotation( TextAnnotationPrivate &amp;amp;dd );
     &lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-23T18:25:03</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7129">
    <title>qt4/src</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7129</link>
    <description>&lt;pre&gt; qt4/src/poppler-annotation.h |    2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit fe28614e7aab6e029f4b420353b67a7eea24de36
Author: Fabio D'Urso &amp;lt;fabiodurso&amp;lt; at &amp;gt;hotmail.it&amp;gt;
Date:   Fri May 18 16:22:46 2012 +0200

    qt4: Make TextAnnotation ctor public

diff --git a/qt4/src/poppler-annotation.h b/qt4/src/poppler-annotation.h
index b897603..e511ec0 100644
--- a/qt4/src/poppler-annotation.h
+++ b/qt4/src/poppler-annotation.h
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -302,6 +302,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; class POPPLER_QT4_EXPORT TextAnnotation : public Annotation
     enum TextType { Linked, InPlace };
     enum InplaceIntent { Unknown, Callout, TypeWriter };
 
+    TextAnnotation( TextType type );
     virtual ~TextAnnotation();
     virtual SubType subType() const;
 
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -360,7 +361,6 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; class POPPLER_QT4_EXPORT TextAnnotation : public Annotation
     void setInplaceIntent( InplaceIntent intent );
 
   private:
-    TextAnnotation( TextType type );
     TextAnnotation( const QDomNode &amp;amp;node );
     TextAnnotation( TextAnnotationPrivate &amp;amp;dd );
     &lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-23T18:02:52</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7128">
    <title>Re: [PATCH] Annotation removal improvements</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7128</link>
    <description>&lt;pre&gt;El Dimarts, 22 de maig de 2012, a les 00:44:26, Fabio D'Urso va escriure:

Carlos, does this work for you?

We'd be commiting this to master only right? No sense in commiting to 0.20 
branch.

Albert

&lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-23T18:01:08</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7127">
    <title>Re: Annotation creation using Poppler</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7127</link>
    <description>&lt;pre&gt;El Divendres, 18 de maig de 2012, a les 17:03:28, Fabio D'Urso va escriure:

Pushed, since this changes the ABI in MSVC it'll have to wait until poppler 
0.22

Albert

&lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-23T17:59:13</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7126">
    <title>Re: [PATCH] Fix automagic lcms dependencies</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7126</link>
    <description>&lt;pre&gt;El Dilluns, 21 de maig de 2012, a les 01:11:34, Maciej Mrozowski va escriure:

Don't have a strong opinion on this, anyone from the "i like autoconf" camp 
can look at the implementation?

Albert
&lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-23T17:49:40</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7125">
    <title>Re: [PATCH] [CMake] Fix automagic lcms dependencies</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7125</link>
    <description>&lt;pre&gt;El Divendres, 18 de maig de 2012, a les 01:56:03, Maciej Mrozowski va 
escriure:

This doesn't work if you do not have lcms2 installed but have lcms installed 
right?

Because it'll go throught the first 

if(ENABLE_LCMS2)  (because i don't have a clue if i have it or not)
and then fail at 
find_package(LCMS2)
and then don't look for LCMS1, no?

Albert
&lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-23T17:46:33</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7124">
    <title>[PATCH] Annotation removal improvements</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7124</link>
    <description>&lt;pre&gt;
The attached patch defines a virtual Annot::removeReferencedObjects method
that each annotation type can reimplement. The base implementation takes
care of removing the appearance stream. The AnnotMarkup implementation
takes care of removing the popup too.


This patch implements the following behavior:
 - When parsing existing annotations, /P is ignored and the in-memory
   page field is always set to the page which the annotation was read
   from (without setting or changing the actual /P value).
 - When adding a new annotation to a given page, /P is set accordingly.

Fabio
_______________________________________________
poppler mailing list
poppler&amp;lt; at &amp;gt;lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/poppler
&lt;/pre&gt;</description>
    <dc:creator>Fabio D'Urso</dc:creator>
    <dc:date>2012-05-21T22:44:26</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7123">
    <title>Branch 'poppler-0.20' - utils/pdfseparate.1</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7123</link>
    <description>&lt;pre&gt; utils/pdfseparate.1 |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 8e504bf2543621973fdaddbd29055ce435540146
Author: Ville SkyttÃ¤ &amp;lt;ville.skytta&amp;lt; at &amp;gt;iki.fi&amp;gt;
Date:   Wed May 16 23:49:01 2012 +0300

    pdfseparate.1: Syntax fixes.

diff --git a/utils/pdfseparate.1 b/utils/pdfseparate.1
index 1eca9d2..077faec 100644
--- a/utils/pdfseparate.1
+++ b/utils/pdfseparate.1
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -13,10 +13,10 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; extract single pages from a Portable Document Format (PDF).
 pdfseparate reads the PDF file
 .IR PDF-file ,
 extracts one or more pages, and writes one PDF file for each page to
-.IR PDF-page-pattern,
+.IR PDF-page-pattern ,
 PDF-page-pattern should contain
-.B %d
-. %d is replaced by the page number.
+.BR %d .
+%d is replaced by the page number.
 .TP
 The PDF-file should not be encrypted.
 .SH OPTIONS
_______________________________________________
poppler mailing list
poppler&amp;lt; at &amp;gt;lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/poppler
&lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-21T21:05:22</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7122">
    <title>utils/pdfseparate.1</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7122</link>
    <description>&lt;pre&gt; utils/pdfseparate.1 |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 918456372548810c9efbf0533fa155034dd081f2
Author: Ville SkyttÃ¤ &amp;lt;ville.skytta&amp;lt; at &amp;gt;iki.fi&amp;gt;
Date:   Wed May 16 23:49:01 2012 +0300

    pdfseparate.1: Syntax fixes.

diff --git a/utils/pdfseparate.1 b/utils/pdfseparate.1
index 1eca9d2..077faec 100644
--- a/utils/pdfseparate.1
+++ b/utils/pdfseparate.1
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -13,10 +13,10 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; extract single pages from a Portable Document Format (PDF).
 pdfseparate reads the PDF file
 .IR PDF-file ,
 extracts one or more pages, and writes one PDF file for each page to
-.IR PDF-page-pattern,
+.IR PDF-page-pattern ,
 PDF-page-pattern should contain
-.B %d
-. %d is replaced by the page number.
+.BR %d .
+%d is replaced by the page number.
 .TP
 The PDF-file should not be encrypted.
 .SH OPTIONS
_______________________________________________
poppler mailing list
poppler&amp;lt; at &amp;gt;lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/poppler
&lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-21T21:03:58</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7121">
    <title>cmake/modules glib/demo test/CMakeLists.txt</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7121</link>
    <description>&lt;pre&gt; cmake/modules/FindGTK.cmake |    8 ++++----
 glib/demo/CMakeLists.txt    |    6 +++---
 test/CMakeLists.txt         |    6 +++---
 3 files changed, 10 insertions(+), 10 deletions(-)

New commits:
commit 892e486addcbcad619613c7be1ca692a0d36d6e5
Author: Albert Astals Cid &amp;lt;aacid&amp;lt; at &amp;gt;kde.org&amp;gt;
Date:   Mon May 21 20:28:42 2012 +0200

    Compile++

diff --git a/glib/CMakeLists.txt b/glib/CMakeLists.txt
index 92e23bd..9831fe7 100644
--- a/glib/CMakeLists.txt
+++ b/glib/CMakeLists.txt
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -69,6 +69,8 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; set(poppler_glib_SRCS
   poppler-movie.cc
   poppler-media.cc
   poppler.cc
+  poppler-cached-file-loader.cc
+  poppler-input-stream.cc
 )
 set(poppler_glib_generated_SRCS
   ${CMAKE_CURRENT_BINARY_DIR}/poppler-enums.c
&lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-21T18:18:55</dc:date>
  </item>
  <textinput rdf:about="http://search.gmane.org/?group=$group=gmane.comp.freedesktop.poppler">
    <title>Search Engine</title>
    <description>Search the mailing list at Gmane</description>
    <name>query</name>
    <link>http://search.gmane.org/?group=$group=gmane.comp.freedesktop.poppler</link>
  </textinput>
</rdf:RDF>


diff --git a/cmake/modules/FindGTK.cmake b/cmake/modules/FindGTK.cmake
index 4d66bd3..1a32483 100644
--- a/cmake/modules/FindGTK.cmake
+++ b/cmake/modules/FindGTK.cmake
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -2,8 +2,8 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
 # Once done this will define
 #
 #  GTK_FOUND - system has GTK
 #  GTK2_CFLAGS - the GTK CFlags
 #  GTK2_LIBRARIES - Link these to use GTK
 #
 # Copyright 2008-2010 Pino Toscano, &amp;lt;pino&amp;lt; at &amp;gt;kde.org&amp;gt;
 #
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -15,8 +15,8 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; include(FindPackageHandleStandardArgs)
 if (NOT WIN32)
   find_package(PkgConfig REQUIRED)
 
-  pkg_check_modules(GTK2 "gtk+-2.0&amp;gt;=2.14" "gdk-pixbuf-2.0" "gthread-2.0" "gio-2.0")
+  pkg_check_modules(GTK3 &lt;/pre&gt;</description>
    <dc:creator>Albert Astals Cid</dc:creator>
    <dc:date>2012-05-21T18:28:58</dc:date>
  </item>
@@
 #
 #  GTK_FOUND - system has GTK
-#  GTK2_CFLAGS - the GTK CFlags
-#  GTK2_LIBRARIES - Link these to use GTK
+#  GTK3_CFLAGS - the GTK CFlags
+#  GTK3_LIBRARIES - Link these to use GTK
 #
 # Copyright 2008-2010 Pino Toscano, &amp;lt;pino&amp;lt; at &amp;gt;kde.org&amp;gt;
  <item rdf:about="http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7120">
    <title>glib/CMakeLists.txt</title>
    <link>http://permalink.gmane.org/gmane.comp.freedesktop.poppler/7120</link>
    <description>&lt;pre&gt; glib/CMakeLists.txt |    2 ++
 1 file changed, 2 insertions(+)

New commits:
commit 794e89ed41d03997778fc4c59b7f1ba557b5e6b7
Author: Albert Astals Cid &amp;lt;aacid&amp;lt; at &amp;gt;kde.org&amp;gt;
Date:   Mon May 21 20:18:42 2012 +0200

    Compile
